@@ -1,7 +1,6 @@
 import logging
 from typing import Callable, Optional
 
-# import zmq.green as zmq
 import zmq
 
 
@@ -18,23 +17,21 @@ class ZeroMQWorker:
         self.poller = zmq.Poller()
         self.poller.register(self.socket, zmq.POLLIN)
 
-    def listen(
-        self, address: str, msg_handler: Callable[[bytes], Optional[bytes]]
-    ) -> None:
+    def listen(self, address: str, msg_handler: Callable[[bytes], Optional[bytes]]) -> None:
         self.socket.connect(address)
-        logging.info("Starting worker %d", self.worker_id)
+        logging.info(f"Starting worker {self.worker_id}")
 
         while True:
-            socks = dict(self.poller.poll(100))
+            socks = dict(self.poller.poll(1000))
             if self.socket in socks:
-                frames = self.socket.recv_multipart(flags=zmq.NOBLOCK)
+                frames = self.socket.recv_multipart()
                 if len(frames) != 2:
-                    logging.error("invalid message received: %s", frames)
+                    logging.error(f"invalid message received: {frames}")
                     continue
 
                 ident, message = frames
                 response = msg_handler(message)
-                self.socket.send_multipart([ident, response], zmq.NOBLOCK)
+                self.socket.send_multipart([ident, response], zmq.DONTWAIT)
 
     def close(self) -> None:
         self.socket.close()
